==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/UmowaKwota.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class UmowaKwota extends GenericDPSObject {
    /**
     * UMOWA_KWOTA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * UMOWA_KWOTA.SLOWO_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long slowoId;

    /**
     * UMOWA_KWOTA.UMOWA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long umowaId;

    /**
     * UMOWA_KWOTA.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return UMOWA_KWOTA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * UMOWA_KWOTA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return UMOWA_KWOTA.SLOWO_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSlowoId() {
        return slowoId;
    }

    /**
     * UMOWA_KWOTA.SLOWO_ID
     *
     * @param slowoId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSlowoId(Long slowoId) {
        this.slowoId = slowoId;
    }

    /**
     * @return UMOWA_KWOTA.UMOWA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getUmowaId() {
        return umowaId;
    }

    /**
     * UMOWA_KWOTA.UMOWA_ID
     *
     * @param umowaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setUmowaId(Long umowaId) {
        this.umowaId = umowaId;
    }

    /**
     * @return UMOWA_KWOTA.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * UMOWA_KWOTA.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        UmowaKwota other = (UmowaKwota) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSlowoId() == null ? other.getSlowoId() == null : this.getSlowoId().equals(other.getSlowoId()))
            && (this.getUmowaId() == null ? other.getUmowaId() == null : this.getUmowaId().equals(other.getUmowaId()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSlowoId() == null) ? 0 : getSlowoId().hashCode());
        result = prime * result + ((getUmowaId() == null) ? 0 : getUmowaId().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", slowoId=").append(slowoId);
        sb.append(", umowaId=").append(umowaId);
        sb.append(", kwota=").append(kwota);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/UmowaKwota.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class UmowaKwota extends GenericDPSObject {
    /**
     * UMOWA_KWOTA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * UMOWA_KWOTA.SLOWO_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long slowoId;

    /**
     * UMOWA_KWOTA.UMOWA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long umowaId;

    /**
     * UMOWA_KWOTA.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return UMOWA_KWOTA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * UMOWA_KWOTA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return UMOWA_KWOTA.SLOWO_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSlowoId() {
        return slowoId;
    }

    /**
     * UMOWA_KWOTA.SLOWO_ID
     *
     * @param slowoId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSlowoId(Long slowoId) {
        this.slowoId = slowoId;
    }

    /**
     * @return UMOWA_KWOTA.UMOWA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getUmowaId() {
        return umowaId;
    }

    /**
     * UMOWA_KWOTA.UMOWA_ID
     *
     * @param umowaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setUmowaId(Long umowaId) {
        this.umowaId = umowaId;
    }

    /**
     * @return UMOWA_KWOTA.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * UMOWA_KWOTA.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        UmowaKwota other = (UmowaKwota) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSlowoId() == null ? other.getSlowoId() == null : this.getSlowoId().equals(other.getSlowoId()))
            && (this.getUmowaId() == null ? other.getUmowaId() == null : this.getUmowaId().equals(other.getUmowaId()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSlowoId() == null) ? 0 : getSlowoId().hashCode());
        result = prime * result + ((getUmowaId() == null) ? 0 : getUmowaId().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", slowoId=").append(slowoId);
        sb.append(", umowaId=").append(umowaId);
        sb.append(", kwota=").append(kwota);
        sb.append("]");
        return sb.toString();
    }
}
